@@ -1,9 +1,11 @@
 package Acme::CPANModules::PortedFrom::Python;
 
+use strict;
+
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-02-05'; # DATE
+our $DATE = '2022-11-13'; # DATE
 our $DIST = 'Acme-CPANModules-PortedFrom-Python'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 our $LIST = {
     summary => "Modules/applications that are ported from (or inspired by) ".
@@ -32,9 +34,18 @@ _
             description => <<'_',
 
 From Plack's documentation: "Plack is like Ruby's Rack or Python's Paste for
-WSGI." Plack and PSGI was created by MIYAGAWA in 2009 and is inspired by both
+WSGI." Plack and PSGI were created by MIYAGAWA in 2009 and were inspired by both
 Python's WSGI specification (hence the dual specification-implementation split)
-and Plack (hence the name).
+and Ruby's Plack (hence the name).
+
+_
+        },
+        {
+            module => 'Data::XLSX::Parser',
+            description => <<'_',
+
+Quoted from the module's documentation: "The implementation of this module is
+highly inspired from Python's FastXLSX library."
 
 _
         },
@@ -56,7 +67,7 @@ Acme::CPANModules::PortedFrom::Python - Modules/applications that are ported fro
 
 =head1 VERSION
 
-This document describes version 0.004 of Acme::CPANModules::PortedFrom::Python (from Perl distribution Acme-CPANModules-PortedFrom-Python), released on 2021-02-05.
+This document describes version 0.005 of Acme::CPANModules::PortedFrom::Python (from Perl distribution Acme-CPANModules-PortedFrom-Python), released on 2022-11-13.
 
 =head1 DESCRIPTION
 
@@ -67,20 +78,34 @@ C<Acme::CPANModules::PortedFrom::*> modules.
 
 If you know of others, please drop me a message.
 
-=head1 ACME::MODULES ENTRIES
+=head1 ACME::CPANMODULES ENTRIES
 
 =over
 
-=item * L<Docopt>
+=item L<Docopt>
 
-=item * L<Getopt::ArgParse>
+Author: L<TOKUHIROM|https://metacpan.org/author/TOKUHIROM>
 
-=item * L<PSGI>
+=item L<Getopt::ArgParse>
+
+Author: L<MYTRAM|https://metacpan.org/author/MYTRAM>
+
+=item L<PSGI>
+
+Author: L<MIYAGAWA|https://metacpan.org/author/MIYAGAWA>
 
 From Plack's documentation: "Plack is like Ruby's Rack or Python's Paste for
-WSGI." Plack and PSGI was created by MIYAGAWA in 2009 and is inspired by both
+WSGI." Plack and PSGI were created by MIYAGAWA in 2009 and were inspired by both
 Python's WSGI specification (hence the dual specification-implementation split)
-and Plack (hence the name).
+and Ruby's Plack (hence the name).
+
+
+=item L<Data::XLSX::Parser>
+
+Author: L<ACIDLEMON|https://metacpan.org/author/ACIDLEMON>
+
+Quoted from the module's documentation: "The implementation of this module is
+highly inspired from Python's FastXLSX library."
 
 
 =back
@@ -96,8 +121,13 @@ document CPAN. See L<Acme::CPANModules> for more details.
 =head2 What are ways to use this Acme::CPANModules module?
 
 Aside from reading this Acme::CPANModules module's POD documentation, you can
-install all the listed modules (entries) using L<cpanmodules> CLI (from
-L<App::cpanmodules> distribution):
+install all the listed modules (entries) using L<cpanm-cpanmodules> script (from
+L<App::cpanm::cpanmodules> distribution):
+
+ % cpanm-cpanmodules -n PortedFrom::Python
+
+Alternatively you can use the L<cpanmodules> CLI (from L<App::cpanmodules>
+distribution):
 
     % cpanmodules ls-entries PortedFrom::Python | cpanm -n
 
@@ -112,6 +142,8 @@ or directly:
 This Acme::CPANModules module also helps L<lcpan> produce a more meaningful
 result for C<lcpan related-mods> command when it comes to finding related
 modules for the modules listed in this Acme::CPANModules module.
+See L<App::lcpan::Cmd::related_mods> for more details on how "related modules"
+are found.
 
 =head1 HOMEPAGE
 
@@ -121,14 +153,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANM
 
 Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModules-PortedFrom-Python>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Acme-CPANModules-PortedFrom-Python/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Acme::CPANModules> - about the Acme::CPANModules namespace
@@ -139,11 +163,37 @@ L<cpanmodules> - CLI tool to let you browse/view the lists
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2018 by perlancar@cpan.org.
+This software is copyright (c) 2022, 2021, 2020, 2018 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModules-PortedFrom-Python>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
